Class: Rails::Generators::ARGVScrubber

Inherits:
Object
  • Object
show all
Defined in:
lib/rails/generators/rails/app/app_generator.rb

Overview

This class handles preparation of the arguments before the AppGenerator is called. The class provides version or help information if they were requested, and also constructs the railsrc file (used for extra configuration options).

This class should be called before the AppGenerator is required and started since it configures and mutates ARGV correctly.

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(argv = ARGV) ⇒ ARGVScrubber

:nodoc:



632
633
634
# File 'lib/rails/generators/rails/app/app_generator.rb', line 632

def initialize(argv = ARGV)
  @argv = argv
end

Class Method Details

.default_rc_fileObject



643
644
645
646
647
648
649
650
651
# File 'lib/rails/generators/rails/app/app_generator.rb', line 643

def self.default_rc_file
  xdg_config_home = ENV["XDG_CONFIG_HOME"].presence || "~/.config"
  xdg_railsrc = File.expand_path("rails/railsrc", xdg_config_home)
  if File.exist?(xdg_railsrc)
    xdg_railsrc
  else
    File.expand_path("~/.railsrc")
  end
end

Instance Method Details

#prepare!Object



636
637
638
639
640
641
# File 'lib/rails/generators/rails/app/app_generator.rb', line 636

def prepare!
  handle_version_request!(@argv.first)
  handle_invalid_command!(@argv.first, @argv) do
    handle_rails_rc!(@argv.drop(1))
  end
end