Class: Rails::Generators::Base

Inherits:
Thor::Group
  • Object
show all
Includes:
Actions, Thor::Actions
Defined in:
lib/rails/generators/base.rb

Class Method Summary collapse

Methods included from Actions

#add_source, #environment, #gem, #gem_group, #generate, #git, #github, #initialize, #initializer, #lib, #rails_command, #rake, #rakefile, #readme, #route, #vendor

Class Method Details

.add_shebang_option!Object

Small macro to add ruby as an option to the generator with proper default value plus an instance helper method called shebang.



396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/rails/generators/base.rb', line 396

def self.add_shebang_option! # :doc:
  class_option :ruby, type: :string, aliases: "-r", default: Thor::Util.ruby_command,
                      desc: "Path to the Ruby binary of your choice", banner: "PATH"

  no_tasks {
    define_method :shebang do
      @shebang ||= begin
        command = if options[:ruby] == Thor::Util.ruby_command
          "/usr/bin/env #{File.basename(Thor::Util.ruby_command)}"
        else
          options[:ruby]
        end
        "#!#{command}"
      end
    end
  }
end

Use Rails default banner.



329
330
331
# File 'lib/rails/generators/base.rb', line 329

def self.banner # :doc:
  "bin/rails generate #{namespace.delete_prefix("rails:")} #{arguments.map(&:usage).join(' ')} [options]".gsub(/\s+/, " ")
end

.base_nameObject

Sets the base_name taking into account the current class namespace.



334
335
336
337
338
# File 'lib/rails/generators/base.rb', line 334

def self.base_name # :doc:
  @base_name ||= if base = name.to_s.split("::").first
    base.underscore
  end
end

.base_rootObject

Returns the base root for a common set of generators. This is used to dynamically guess the default source root.



236
237
238
# File 'lib/rails/generators/base.rb', line 236

def self.base_root
  __dir__
end

.class_option(name, options = {}) ⇒ Object

Make class option aware of Rails::Generators.options and Rails::Generators.aliases.



217
218
219
220
221
222
# File 'lib/rails/generators/base.rb', line 217

def self.class_option(name, options = {}) # :nodoc:
  options[:desc]    = "Indicates when to generate #{name.to_s.humanize.downcase}" unless options.key?(:desc)
  options[:aliases] = default_aliases_for_option(name, options)
  options[:default] = default_value_for_option(name, options)
  super(name, options)
end

.default_aliases_for_option(name, options) ⇒ Object

Returns default aliases for the option name given doing a lookup in Rails::Generators.aliases.



357
358
359
# File 'lib/rails/generators/base.rb', line 357

def self.default_aliases_for_option(name, options) # :doc:
  default_for_option(Rails::Generators.aliases, name, options, options[:aliases])
end

.default_for_option(config, name, options, default) ⇒ Object

Returns default for the option name given doing a lookup in config.



362
363
364
365
366
367
368
369
370
371
372
# File 'lib/rails/generators/base.rb', line 362

def self.default_for_option(config, name, options, default) # :doc:
  if generator_name && (c = config[generator_name.to_sym]) && c.key?(name)
    c[name]
  elsif base_name && (c = config[base_name.to_sym]) && c.key?(name)
    c[name]
  elsif config[:rails].key?(name)
    config[:rails][name]
  else
    default
  end
end

.default_generator_rootObject

:doc:



422
423
424
425
# File 'lib/rails/generators/base.rb', line 422

def self.default_generator_root # :doc:
  path = File.expand_path(File.join(base_name, generator_name), base_root)
  path if File.exist?(path)
end

.default_source_rootObject

Returns the default source root for a given generator. This is used internally by Rails to set its generators source root. If you want to customize your source root, you should use source_root.



227
228
229
230
231
232
# File 'lib/rails/generators/base.rb', line 227

def self.default_source_root
  return unless base_name && generator_name
  return unless default_generator_root
  path = File.join(default_generator_root, "templates")
  path if File.exist?(path)
end

.default_value_for_option(name, options) ⇒ Object

Returns the default value for the option name given doing a lookup in Rails::Generators.options.



351
352
353
# File 'lib/rails/generators/base.rb', line 351

def self.default_value_for_option(name, options) # :doc:
  default_for_option(Rails::Generators.options, name, options, options[:default])
end

.desc(description = nil) ⇒ Object

Tries to get the description from a USAGE file one folder above the source root otherwise uses a default description.



41
42
43
44
45
46
47
48
49
# File 'lib/rails/generators/base.rb', line 41

def self.desc(description = nil)
  return super if description

  @desc ||= if usage_path
    ERB.new(File.read(usage_path)).result(binding)
  else
    "Description:\n    Create #{base_name.humanize.downcase} files for #{generator_name} generator."
  end
end

.exit_on_failure?Boolean

:nodoc:

Returns:

  • (Boolean)


29
30
31
# File 'lib/rails/generators/base.rb', line 29

def self.exit_on_failure? # :nodoc:
  false
end

.generator_nameObject

Removes the namespaces and get the generator name. For example, Rails::Generators::ModelGenerator will return “model” as generator name.



342
343
344
345
346
347
# File 'lib/rails/generators/base.rb', line 342

def self.generator_name # :doc:
  @generator_name ||= if generator = name.to_s.split("::").last
    generator.delete_suffix!("Generator")
    generator.underscore
  end
end

.hide!Object

Convenience method to hide this generator from the available ones when running rails generator command.



61
62
63
# File 'lib/rails/generators/base.rb', line 61

def self.hide!
  Rails::Generators.hide_namespace(namespace)
end

.hook_for(*names, &block) ⇒ Object

Invoke a generator based on the value supplied by the user to the given option named “name”. A class option is created when this method is invoked and you can set a hash to customize it.

Examples

module Rails::Generators
  class ControllerGenerator < Base
    hook_for :test_framework, aliases: "-t"
  end
end

The example above will create a test framework option and will invoke a generator based on the user supplied value.

For example, if the user invoke the controller generator as:

$ bin/rails generate controller  --test-framework=test_unit

The controller generator will then try to invoke the following generators:

"rails:test_unit", "test_unit:controller", "test_unit"

Notice that “rails:generators:test_unit” could be loaded as well, what Rails looks for is the first and last parts of the namespace. This is what allows any test framework to hook into Rails as long as it provides any of the hooks above.

Options

The first and last part used to find the generator to be invoked are guessed based on class invokes hook_for, as noticed in the example above. This can be customized with two options: :in and :as.

Let’s suppose you are creating a generator that needs to invoke the controller generator from test unit. Your first attempt is:

class AwesomeGenerator < Rails::Generators::Base
  hook_for :test_framework
end

The lookup in this case for test_unit as input is:

"test_unit:awesome", "test_unit"

Which is not the desired lookup. You can change it by providing the :as option:

class AwesomeGenerator < Rails::Generators::Base
  hook_for :test_framework, as: :controller
end

And now it will look up at:

"test_unit:controller", "test_unit"

Similarly, if you want it to also look up in the rails namespace, you just need to provide the :in value:

class AwesomeGenerator < Rails::Generators::Base
  hook_for :test_framework, in: :rails, as: :controller
end

And the lookup is exactly the same as previously:

"rails:test_unit", "test_unit:controller", "test_unit"

Switches

All hooks come with switches for user interface. If you do not want to use any test framework, you can do:

$ bin/rails generate controller  --skip-test-framework

Or similarly:

$ bin/rails generate controller  --no-test-framework

Boolean hooks

In some cases, you may want to provide a boolean hook. For example, webrat developers might want to have webrat available on controller generator. This can be achieved as:

Rails::Generators::ControllerGenerator.hook_for :webrat, type: :boolean

Then, if you want webrat to be invoked, just supply:

$ bin/rails generate controller  --webrat

The hooks lookup is similar as above:

"rails:generators:webrat", "webrat:generators:controller", "webrat"

Custom invocations

You can also supply a block to hook_for to customize how the hook is going to be invoked. The block receives two arguments, an instance of the current class and the class to be invoked.

For example, in the resource generator, the controller should be invoked with a pluralized class name. But by default it is invoked with the same name as the resource generator, which is singular. To change this, we can give a block to customize how the controller can be invoked.

hook_for :resource_controller do |instance, controller|
  instance.invoke controller, [ instance.name.pluralize ]
end


174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/rails/generators/base.rb', line 174

def self.hook_for(*names, &block)
  options = names.extract_options!
  in_base = options.delete(:in) || base_name
  as_hook = options.delete(:as) || generator_name

  names.each do |name|
    unless class_options.key?(name)
      defaults = if options[:type] == :boolean
        {}
      elsif [true, false].include?(default_value_for_option(name, options))
        { banner: "" }
      else
        { desc: "#{name.to_s.humanize} to be invoked", banner: "NAME" }
      end

      class_option(name, defaults.merge!(options))
    end

    klass = self

    singleton_class.define_method("#{name}_generator") do
      value = class_options[name].default
      Rails::Generators.find_by_namespace(klass.generator_name, value)
    end

    hooks[name] = [ in_base, as_hook ]
    invoke_from_option(name, options, &block)
  end
end

.hooksObject

Keep hooks configuration that are used on prepare_for_invocation.



375
376
377
# File 'lib/rails/generators/base.rb', line 375

def self.hooks # :nodoc:
  @hooks ||= from_superclass(:hooks, {})
end

.inherited(base) ⇒ Object

Cache source root and add lib/generators/base/generator/templates to source paths.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/rails/generators/base.rb', line 242

def self.inherited(base) # :nodoc:
  super

  # Invoke source_root so the default_source_root is set.
  base.source_root

  if base.name && !base.name.end_with?("Base")
    Rails::Generators.subclasses << base

    Rails::Generators.templates_path.each do |path|
      if base.name.include?("::")
        base.source_paths << File.join(path, base.base_name, base.generator_name)
      else
        base.source_paths << File.join(path, base.generator_name)
      end
    end
  end
end

.namespace(name = nil) ⇒ Object

Convenience method to get the namespace from the class name. It’s the same as Thor default except that the Generator at the end of the class is removed.



54
55
56
57
# File 'lib/rails/generators/base.rb', line 54

def self.namespace(name = nil)
  return super if name
  @namespace ||= super.delete_suffix("_generator").sub(/:generators:/, ":")
end

.prepare_for_invocation(name, value) ⇒ Object

Prepare class invocation to search on Rails namespace if a previous added hook is being used.



381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/rails/generators/base.rb', line 381

def self.prepare_for_invocation(name, value) # :nodoc:
  return super unless value.is_a?(String) || value.is_a?(Symbol)

  if value && constants = hooks[name]
    value = name if TrueClass === value
    Rails::Generators.find_by_namespace(value, *constants)
  elsif klass = Rails::Generators.find_by_namespace(value)
    klass
  else
    super
  end
end

.remove_hook_for(*names) ⇒ Object

Remove a previously added hook.

remove_hook_for :orm


207
208
209
210
211
212
213
214
# File 'lib/rails/generators/base.rb', line 207

def self.remove_hook_for(*names)
  remove_invocation(*names)

  names.each do |name|
    singleton_class.undef_method("#{name}_generator")
    hooks.delete(name)
  end
end

.source_root(path = nil) ⇒ Object

Returns the source root for this generator using default_source_root as default.



34
35
36
37
# File 'lib/rails/generators/base.rb', line 34

def self.source_root(path = nil)
  @_source_root = path if path
  @_source_root ||= default_source_root
end

.usage_pathObject

:doc:



414
415
416
417
418
419
420
# File 'lib/rails/generators/base.rb', line 414

def self.usage_path # :doc:
  paths = [
    source_root && File.expand_path("../USAGE", source_root),
    default_generator_root && File.join(default_generator_root, "USAGE")
  ]
  paths.compact.detect { |path| File.exist? path }
end